@@ -1,7 +1,9 @@
 `effectsize` <-
 function(tstat,ntilde,m)
 {
-cm=gamma(m/2)/(sqrt(m/2)*gamma((m-1)/2))
+# cm=gamma(m/2)/(sqrt(m/2)*gamma((m-1)/2))
+ln.cm<-lgamma(m/2)-log(sqrt(m/2))-lgamma((m-1)/2)  
+cm<-exp(ln.cm)
 d=tstat/sqrt(ntilde)
 dprime=cm*d
 terme1=m/((m-2)*ntilde)
